From 683b402965e68800337af8f9b237d28be273c0d8 Mon Sep 17 00:00:00 2001
From: Andrew Martin <andrew.thaddeus@gmail.com>
Date: Wed, 18 Mar 2020 13:19:04 -0400
Subject: [PATCH] Switch GHC.Prim to GHC.Exts

---
 Data/ByteArray/Bytes.hs              | 2 +-
 Data/ByteArray/ScrubbedBytes.hs      | 2 +-
 Data/Memory/Encoding/Base16.hs       | 2 +-
 Data/Memory/Encoding/Base32.hs       | 2 +-
 Data/Memory/Encoding/Base64.hs       | 2 +-
 Data/Memory/Hash/FNV.hs              | 2 +-
 Data/Memory/Internal/CompatPrim.hs   | 2 +-
 Data/Memory/Internal/CompatPrim64.hs | 4 ++--
 8 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/Data/ByteArray/Bytes.hs b/Data/ByteArray/Bytes.hs
index 588247e..e79f81c 100644
--- a/Data/ByteArray/Bytes.hs
+++ b/Data/ByteArray/Bytes.hs
@@ -17,7 +17,7 @@ module Data.ByteArray.Bytes
     ) where
 
 import           GHC.Types
-import           GHC.Prim
+import           GHC.Exts hiding (toList)
 import           GHC.Ptr
 #if MIN_VERSION_base(4,9,0)
 import           Data.Semigroup
diff --git a/Data/ByteArray/ScrubbedBytes.hs b/Data/ByteArray/ScrubbedBytes.hs
index 80c2d03..4567567 100644
--- a/Data/ByteArray/ScrubbedBytes.hs
+++ b/Data/ByteArray/ScrubbedBytes.hs
@@ -15,7 +15,7 @@ module Data.ByteArray.ScrubbedBytes
     ) where
 
 import           GHC.Types
-import           GHC.Prim
+import           GHC.Exts hiding (toList)
 import           GHC.Ptr
 #if MIN_VERSION_base(4,9,0)
 import           Data.Semigroup
diff --git a/Data/Memory/Encoding/Base16.hs b/Data/Memory/Encoding/Base16.hs
index fd230ec..cf2d02b 100644
--- a/Data/Memory/Encoding/Base16.hs
+++ b/Data/Memory/Encoding/Base16.hs
@@ -24,7 +24,7 @@ module Data.Memory.Encoding.Base16
 import           Data.Memory.Internal.Compat
 import           Data.Word
 import           Data.Bits ((.|.))
-import           GHC.Prim
+import           GHC.Exts
 import           GHC.Types
 import           GHC.Word
 import           Control.Monad
diff --git a/Data/Memory/Encoding/Base32.hs b/Data/Memory/Encoding/Base32.hs
index 9f492a2..1174d99 100644
--- a/Data/Memory/Encoding/Base32.hs
+++ b/Data/Memory/Encoding/Base32.hs
@@ -25,7 +25,7 @@ import           Data.Memory.Internal.Compat
 import           Data.Memory.Internal.CompatPrim
 import           Data.Word
 import           Data.Bits ((.|.))
-import           GHC.Prim
+import           GHC.Exts
 import           GHC.Word
 import           Control.Monad
 import           Foreign.Storable
diff --git a/Data/Memory/Encoding/Base64.hs b/Data/Memory/Encoding/Base64.hs
index 9803875..01cfbe6 100644
--- a/Data/Memory/Encoding/Base64.hs
+++ b/Data/Memory/Encoding/Base64.hs
@@ -30,7 +30,7 @@ import           Data.Memory.Internal.Compat
 import           Data.Memory.Internal.CompatPrim
 import           Data.Memory.Internal.Imports
 import           Data.Bits ((.|.))
-import           GHC.Prim
+import           GHC.Exts
 import           GHC.Word
 import           Foreign.Storable
 import           Foreign.Ptr (Ptr)
diff --git a/Data/Memory/Hash/FNV.hs b/Data/Memory/Hash/FNV.hs
index 89d78b5..8966835 100644
--- a/Data/Memory/Hash/FNV.hs
+++ b/Data/Memory/Hash/FNV.hs
@@ -29,7 +29,7 @@ import           Data.Memory.Internal.CompatPrim
 import           Data.Memory.Internal.CompatPrim64
 import           Data.Memory.Internal.Imports
 import           GHC.Word
-import           GHC.Prim hiding (Word64#, Int64#)
+import           GHC.Exts hiding (Word64#, Int64#)
 import           GHC.Types
 import           GHC.Ptr
 
diff --git a/Data/Memory/Internal/CompatPrim.hs b/Data/Memory/Internal/CompatPrim.hs
index e4ab5cd..34b8e46 100644
--- a/Data/Memory/Internal/CompatPrim.hs
+++ b/Data/Memory/Internal/CompatPrim.hs
@@ -21,7 +21,7 @@ module Data.Memory.Internal.CompatPrim
     , booleanPrim
     ) where
 
-import GHC.Prim
+import GHC.Exts
 
 -- | byteswap Word# to or from Big Endian
 --
diff --git a/Data/Memory/Internal/CompatPrim64.hs b/Data/Memory/Internal/CompatPrim64.hs
index b6d2bd7..d639d5e 100644
--- a/Data/Memory/Internal/CompatPrim64.hs
+++ b/Data/Memory/Internal/CompatPrim64.hs
@@ -52,7 +52,7 @@ module Data.Memory.Internal.CompatPrim64
 
 
 #if WORD_SIZE_IN_BITS == 64
-import GHC.Prim hiding (Word64#, Int64#)
+import GHC.Exts hiding (Word64#, Int64#, uncheckedShiftL64#, uncheckedShiftRL64#)
 
 #if __GLASGOW_HASKELL__ >= 708
 type OutBool = Int#
@@ -149,7 +149,7 @@ w64# w _ _ = w
 
 #elif WORD_SIZE_IN_BITS == 32
 import GHC.IntWord64
-import GHC.Prim (Word#)
+import GHC.Exts (Word#)
 
 timesWord64# :: Word64# -> Word64# -> Word64#
 timesWord64# a b =
